@@ -26,11 +26,6 @@ import codecs
 from string import rfind
 
 
-def stripWhitespaceAndComments(line):
-	if u"!" in line:
-		line = line[0:line.find(u"!")]
-	return line.strip()
-
 def addDiacritics(line):
 	if u"[Nm]" in line or (u"[Sn][Ny]" in line and u"Omistusliite" in line):
 		middle = line.find(u":")
@@ -121,10 +116,10 @@ def appendLexicon(lexiconName, lines, lexcFile):
 		                u"NormaaliYsJatkoOl", u"Luku", u"Valo_w", u"Valo_s", u"Valo_sl", \
 		                u"Koira", u"Koira_w", u"Koira_s", u"MonikonGenetiiviInJatko", \
 		                u"Koira_w_monikko", u"Koira_w_yksikkö", u"Puu", u"Maa_l", u"Maa_s", \
-		                u"OlVLoppu", u"MonikonNominatiivinJatko"]:
+		                u"OlVLoppu", u"MonikonNominatiivinJatko", u"YksikönGenetiivinJatkoEiYs"]:
 			appendLines(u"LukusananJälkiliite", realName, lines, lexcFile)
 			appendLines(u"Asemosana", realName, lines, lexcFile)
-		if OPTIONS["sukija"] and realName in [u"SukijaYhteisetHMuodot"]:
+		if (OPTIONS["sukija"] or OPTIONS["vanhat"]) and realName in [u"YhteisetHTaivutusmuodot"]:
 			appendLines(u"LukusananJälkiliite", realName, lines, lexcFile)
 			appendLines(u"Asemosana", realName, lines, lexcFile)
 	else:
@@ -145,12 +140,9 @@ while True:
 	linecount = linecount + 1
 	if line_orig == u'':
 		break
-	if line_orig.startswith(u'?Sukija'):
-		if OPTIONS["sukija"]:
-			line_orig = line_orig[7:]
-		else:
-			continue
-	line = stripWhitespaceAndComments(line_orig)
+	line = generate_lex_common.filterVfstInput(line_orig, OPTIONS)
+	if line is None:
+		continue
 	if line.startswith(u'LEXICON '):
 		if lexicon != u"":
 			appendLexicon(lexicon, lexcLines, lexcFile)
@@ -237,6 +229,8 @@ for sija in MULTI.keys():
 		numeralLines.append(diacritic + u":" + diacritic + u"\tOlI_<A>\t;")
 	appendLines(u"Lukusana", sija + u"1", numeralLines, lexcFile)
 
+MULTI_ORDINAL_BASES = [u"kymmenes", u"sadas", u"tuhannes", u"miljoonas", u"miljardis"]
+
 MULTI_ORDINALS = {
 	u"SgNy": [u"kymmenennen", u"sadannen", u"tuhannennen", u"miljoonannen", u"miljardinnen"],
 	u"SpNy": [u"kymmenettä", u"sadannetta", u"tuhannetta", u"miljoonannetta", u"miljardinnetta"],
@@ -267,13 +261,14 @@ MULTI_ORDINALS = {
 for sija in MULTI_ORDINALS.keys():
 	diacritic = u"@U.LS." + sija.upper() + u"@"
 	lexiconName = u"Järjestysluku" + sija + u"39"
+	tagName = u"[" + sija.replace(u"N", u"][N") + u"]"
 	
 	lexcFile.write(u"LEXICON " + lexiconName + u"Kertoimet\n")
-	lexcFile.write(u"[Bc]" + diacritic + MULTI_ORDINALS[sija][0] + u":" + diacritic + MULTI_ORDINALS[sija][0] + u"\t" + lexiconName + u"_ä\t;\n")
-	lexcFile.write(u"[Bc]" + diacritic + MULTI_ORDINALS[sija][1] + u":" + diacritic + MULTI_ORDINALS[sija][1] + u"\t" + lexiconName + u"_a\t;\n")
-	lexcFile.write(u"[Bc]" + diacritic + MULTI_ORDINALS[sija][2] + u":" + diacritic + MULTI_ORDINALS[sija][2] + u"\t" + lexiconName + u"_a\t;\n")
-	lexcFile.write(u"[Bc]" + diacritic + MULTI_ORDINALS[sija][3] + u":" + diacritic + MULTI_ORDINALS[sija][3] + u"\t" + lexiconName + u"_a\t;\n")
-	lexcFile.write(u"[Bc]" + diacritic + MULTI_ORDINALS[sija][4] + u":" + diacritic + MULTI_ORDINALS[sija][4] + u"\t" + lexiconName + u"_a\t;\n")
+	lexcFile.write(u"[Bc]" + diacritic + u"[Xp]" + MULTI_ORDINAL_BASES[0] + u"[X]" + tagName + MULTI_ORDINALS[sija][0] + u":" + diacritic + MULTI_ORDINALS[sija][0] + u"\t" + lexiconName + u"_ä\t;\n")
+	lexcFile.write(u"[Bc]" + diacritic + u"[Xp]" + MULTI_ORDINAL_BASES[1] + u"[X]" + tagName + MULTI_ORDINALS[sija][1] + u":" + diacritic + MULTI_ORDINALS[sija][1] + u"\t" + lexiconName + u"_a\t;\n")
+	lexcFile.write(u"[Bc]" + diacritic + u"[Xp]" + MULTI_ORDINAL_BASES[2] + u"[X]" + tagName + MULTI_ORDINALS[sija][2] + u":" + diacritic + MULTI_ORDINALS[sija][2] + u"\t" + lexiconName + u"_a\t;\n")
+	lexcFile.write(u"[Bc]" + diacritic + u"[Xp]" + MULTI_ORDINAL_BASES[3] + u"[X]" + tagName + MULTI_ORDINALS[sija][3] + u":" + diacritic + MULTI_ORDINALS[sija][3] + u"\t" + lexiconName + u"_a\t;\n")
+	lexcFile.write(u"[Bc]" + diacritic + u"[Xp]" + MULTI_ORDINAL_BASES[4] + u"[X]" + tagName + MULTI_ORDINALS[sija][4] + u":" + diacritic + MULTI_ORDINALS[sija][4] + u"\t" + lexiconName + u"_a\t;\n")
 	
 	numeralLines = []
 	if sija in [u"SgNy", u"SgNm"]:
